import $ from "zepto";

var Utils = (function(window){
  /**
  *@Function: 获取url参数
  *@param url : url 中参数名
  */
  var GetQueryString = function (url) {
    var reg = new RegExp("(^|&)" + url + "=([^&]*)(&|$)","i");
    var r = window.location.search.substr(1).match(reg);
    if (r!=null) return (r[2]); return null;
  }
  /*
  * 正则验证
  */
  var regExp = (function(){
    return{
      isMobil:function (s){
        var patten= /^(\+?0?86\-?)?1[345789]\d{9}$/;
        if (!patten.test(s))
          return false;
        return true;
      },
      isDigit:function(s){
        var patten=/^[0-9]{1,20}$/;
        if (!patten.test(s))
          return false;
        return true;
      },
      isEmail: function(){
        var patten = /^\\w+((-\\w+)|(\\.\\w+))*\\@[A-Za-z0-9]+((\\.|-)[A-Za-z0-9]+)*\\.[A-Za-z0-9]+$/;
        if (!patten.test(s))
          return false;
        return true;
      }
    }
  })();

  var J2S = function(obj){
    if( typeof(obj) == "object" && Object.prototype.toString.call(obj).toLowerCase() == "[object object]" && !obj.length ){
      return JSON.stringify(obj);
    }else{
      throw new Error("参数必须是json对象!");
    }

  }
  //string-->json
  var S2J = function(strs){
    if( typeof(strs) === "string"){
      return JSON.parse(strs);
    }else{
      throw new Error("参数必须是String类型!");
    }
  }
  /**
  * @Function判断手机设备
  * @return "IOS","ANDROID"
  */
  var Device = function(){
    var ua = navigator.userAgent;
    var ipad = ua.match(/(iPad).*OS\s([\d_]+)/),
        isIphone = !ipad && ua.match(/(iPhone\sOS)\s([\d_]+)/),
        isAndroid = ua.match(/(Android)\s+([\d.]+)/),
        isMobile = isIphone || isAndroid;

    if( isIphone || ipad ){
      return "IOS";
    }else{
      return "ANDROID";
    }
  }
  /**
  * @Function 判断是否是微信浏览器
  */
  var isWeiXin = function(){
    var ua = window.navigator.userAgent.toLowerCase();
    if(ua.match(/MicroMessenger/i) == 'micromessenger'){
      return true;
    }else{
      return false;
    }
  }
  /**
  * @Function 隐藏手机号 比如 15021231608 ==> 150****1608
  */
  var telStar = function(tel){

    var reg = /(\d{3})\d{4}(\d{4})/;

    var phonenumber = tel.replace(reg,"$1****$2");

    return phonenumber;
  }

  /**
  * @Function 判断是测试环境还是线上环境
  */
  var isDevelopment  = function(){
    return !!(window.location.host.match(/localhost|vtest.boqii.com|stest.boqii.com|mtest.boqii.com|slocal.boqii.com|127\.0\.0\.1/))
  }

  /**
  * @Function 判断浏览器是否支持localStorage
  */
  var isLocalStorageSupported = function(){
      var testKey = 'boqi',
          storage = window.sessionStorage;
      try {
          storage.setItem(testKey, 'testValue');
          storage.removeItem(testKey);
          return true;
      } catch (error) {
          return false;
      }
  }

  /**
  * @Function 存cookie or localStorage
  * @用法 1. 存cookie storageInfo("cookie").set("name","andy"......);
  *      2. 存localStorage storageInfo("localStorage").set("name","nady")
  */
  var storageInfo=function(type){

    var supportStorage = (type === "localStorage") ? true :false;

    return {
      set:function(name,value,expires,path,domain){
        if(supportStorage){
          window.localStorage.setItem(name,value);
        }else{

          if(typeof expires=="undefined"){
            expires=new Date(new Date().getTime()+(10000000*60*60*24*30)).toGMTString();
          }
          document.cookie=name+"="+escape(value)+((expires)?";expires="+expires:"")+((path)?";path="+path:";path=/")+((domain)?";domain="+domain:"");
        }
      },
      get:function(name){
        if(supportStorage){
          return window.localStorage.getItem(name);
        }else{
          var arr=document.cookie.match(new RegExp("(^| )"+name+"=([^;]*)(;|$)"));
          if(arr!=null){return unescape(arr[2]);}
          return null;
        }
      },
      clear:function(name,path,domain){
        if(supportStorage){
          window.localStorage.removeItem(name);
        }else{
          if(this.get(name)){
            document.cookie=name+"="+((path)?"; path="+path:"; path=/")+((domain)?"; domain="+domain:"")+";expires=Fri, 02-Jan-1970 00:00:00 GMT";
          }
        }
      }
    }
  };
  /**
  *某个值是否存在
  */
  var isSet = function(entity){
    return typeof entiry !== "undefined" && entiry !== null;
  }
  /*
  *判断对象是否为空
  */
  var isEmpty = function( obj ) {
    for ( var name in obj ) {
      return false;
    }
    return true;
  };

  var getChannel = function() {
    return '2_7';
  }

  return {
    GetQueryString,
    regExp,
    J2S,
    S2J,
    Device,
    telStar,
    isDevelopment,
    isLocalStorageSupported,
    isWeiXin,
    storageInfo,
    isSet,
    isEmpty,
    getChannel
  }

})(window);

//======导出模块=======
//AMD/CMD
//==exports.Util = Util;
//==module.exports = {
//  Util: Util
//}
//es6 模块
export default Utils
